<?php
App::uses('Component', 'Controller');

class GaEcommerceComponent extends Component {

	protected $_controller = null;

	protected $_gaItems = [];

	/**
	 * Sets a reference to the calling controller from within the component.
	 *
	 * @see Component::initialize()
	 */
	public function initialize(Controller $controller) {
		parent::initialize($controller);
		$this->_controller = $controller;
	}

	/**
	 * Returns JSON encoded transaction data for GA e-commerce tracking.
	 *
	 * @param string $salesRef Transaction ID
	 * @param float $totalCost Total cost
	 * @param float $shippingCost Optional shipping/delivery cost
	 * @return string
	 */
	public function transaction($salesRef, $totalCost, $shippingCost = 0) {
		$data = [
			'id' => $salesRef,
			'revenue' => $totalCost
		];
		if (!empty($shippingCost)) {
			$data['shipping'] = $shippingCost;
		}
		return json_encode($data);
	}

	/**
	 * Adds an item to the gaItems array (and returns the item).
	 *
	 * @param string $salesRef Transaction ID
	 * @param string $name Product name
	 * @param string $sku SKU/Product code
	 * @param float $price Unit price
	 * @param int $quantity Quantity
	 * @param string $category Optional category name
	 * @return string JSON
	 */
	public function addItem($salesRef, $name, $sku, $price, $quantity = 1, $category = null) {
		$data = [
			'id' => $salesRef,
			'name' => $name,
			'sku' => $sku,
			'price' => $price,
			'quantity' => $quantity
		];
		if (!empty($category)) {
			$data['category'] = $category;
		}

		$data = json_encode($data);
		$this->_gaItems[] = $data;
		return $data;
	}

	/**
	 * Returns an array of JSON encoded items.
	 *
	 * @return array
	 */
	public function items() {
		return $this->_gaItems;
	}

}
